/// <reference types="node" />
import * as EventEmitter from 'events';
/**
 * Clase para crear un transport, remplazando un broker.
 *
 * @export
 * @class HttpTransport
 * @extends {EventEmitter}
 */
export default class HttpTransport extends EventEmitter {
    /**
     * Instancia de express
     *
     * @private
     * @type {express.Application}
     * @memberof HttpTransport
     */
    private app;
    /**
     * Puerto en el que inicia el servidor http
     *
     * @private
     * @type {number}
     * @memberof HttpTransport
     */
    private port;
    /**
     * Manejador de logs
     *
     * @private
     * @type {*}
     * @memberof HttpTransport
     */
    private logs;
    /**
     * Topico del servicio
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private topicName;
    /**
     * Hostname
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private hostname;
    /**
     * Nombre de la aplicacion
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private appname;
    /**
     * Numero de la version
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private version;
    /**
     * Nombre del servicio
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private serviceName;
    /**
     * Topico
     *
     * @private
     * @type {string}
     * @memberof HttpTransport
     */
    private topic;
    /**
     * Creates an instance of HttpTransport.
     * @param {string} topic
     * @memberof HttpTransport
     */
    constructor(topic: string, version?: string, appname?: string, // Nombre de la aplicacion
    serviceName?: string);
    /**
     * Metodo para crear los datos necesarios de la metadata.
     *
     * @private
     * @returns {Metadata}
     * @memberof HttpTransport
     */
    private createMetaData;
    /**
     * Metodo para ejecutar una peticion.
     *
     * @private
     * @param {DataRequest} request
     * @returns {Promise<DataRequest>}
     * @memberof HttpTransport
     */
    private process;
    /**
     * Metodo para preparar los datos requeridos de la peticion
     *
     * @private
     * @param {string} method
     * @param {*} data
     * @param {*} filters
     * @param {string} uuid
     * @param {*} headers
     * @returns {DataRequest}
     * @memberof HttpTransport
     */
    private prepare;
    /**
     * Handler para las peticiones desde el cliente.
     *
     * @private
     * @param {express.Request} req
     * @param {express.Response} resp
     * @memberof HttpTransport
     */
    private handler;
    /**
     *  Metodo que inicia el servidor HTTP.
     *  @public
     */
    start(): void;
}
