export interface ConfConsumer {
    kafkaHost: string;
    groupId: string;
    fromOffset: TypeOffset;
    OutOfRangeOffset?: TypeOffset;
}
/**
 * Interfaces de multicallback
 */
export interface Multicallback {
    method: string;
    name: string;
    span?: any;
}
/**
 * Intercaces del metadata
 */
export interface Metadata {
    id_operacion?: string | number;
    id_transaction: string;
    intents?: number;
    callback?: string;
    owner: string;
    uowner?: string;
    uworker?: string;
    worker?: string;
    asynchronous?: boolean;
    mtype?: string;
    bifurcacion?: boolean;
    time?: string;
    from?: string;
    original_method?: string;
    method?: string;
    uuid?: any;
    metadata_inicial?: any;
    data_inicial?: any;
    callbacks?: Multicallback[];
    deviceType?: string;
    hostname?: string;
    framework?: string;
    filters?: any;
    span?: any;
}
export interface Header {
    Asynchronous: boolean;
    Authorizacion: boolean;
}
export interface ErrorResponseData {
    respose: ErrorBase;
}
export interface Response {
    data: ErrorResponseData | any;
}
export interface DataRequest {
    uuid?: string;
    metadata: Metadata;
    headers?: Header;
    data?: object | ErrorResponseData;
    response?: Response;
}
export declare enum TypeService {
    'Fork' = "fork",
    'Worker' = "worker"
}
export declare enum TypeOffset {
    'Earliest' = "earliest",
    'Latest' = "latest"
}
export interface ConfService {
    App: string;
    Name: string;
    Version: string;
    Type?: TypeService;
    Public?: boolean;
    Broker?: string[];
    Nats?: string[];
    Debug?: boolean;
    ClearQueque?: boolean;
    Fork?: boolean;
    Thread?: boolean;
    Offset?: TypeOffset;
    OutOfRangeOffset?: TypeOffset;
    PartitionerType?: PartitionerType;
}
export interface Service {
    App: string;
    Service: string;
    Version: string;
    Framework?: string;
}
export interface ResponseMessage {
    error: ErrorMetadata;
    fork: boolean;
    response: any;
}
export interface ErrorBase {
    errorCode: number;
    userMessage: string;
}
export interface ErrorMetadata extends ErrorBase {
    Service?: Service;
}
export declare enum HttpMethod {
    GET = "GET",
    POST = "POST",
    PUT = "PUT",
    DELETE = "DELETE"
}
export declare enum Actions {
    DEFAULT = "GET",
    CREATE = "POST",
    LIST = "GET",
    GET = "GET",
    UPDATE = "PUT",
    DELETE = "DELETE"
}
export declare enum PartitionerType {
    RANDOM = 1,
    CYCLIC = 2,
    KEYED = 3,
    CUSTOM = 4
}
export interface ErrorMs {
    [index: number]: string;
}
export interface Worker {
    id?: string;
    App: string;
    Name: string;
    Version: string;
}
export interface ConfForks {
    [index: string]: Worker;
}
export interface ConfReflect {
    key: string;
    returntype: any;
    type: any;
}
export interface ConfFork {
    action?: Actions;
    fork: string;
    data?: any;
    fnc?: string;
}
export interface InitConfigFork {
    id?: string;
    conf: Worker;
    action?: Actions;
    fork: string;
    data?: any;
    fnc?: (response: any, request: any) => any;
}
export interface ConfLogs {
    Type: TypeLogs;
    Message: string;
}
export interface MessageWorker {
    Type: TypeMessage;
    Data: any;
}
export interface LogsFormat {
    id: string;
    idApp: string;
    idComponent: string;
    level: number;
    time: number;
    msg: string;
    pid: number;
    hostname: string;
}
export declare enum TypeLogs {
    Info = "INFO",
    Error = "ERROR",
    Warning = "WARNING",
    Log = "LOG"
}
export declare enum TypeMessage {
    Logs = "LOGS",
    Message = "MESSAGE",
    Publish = "PUBLISH"
}
export declare enum LogsTypes {
    Fatal = 60,
    Error = 50,
    Warn = 40,
    Info = 30,
    Debug = 20,
    Trace = 10
}
