"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
class Util {
    /**
     * Metodo para validar si un elemento es una promesa
     * @param obj Objecto a validar
     */
    static isPromise(obj) {
        return (obj &&
            (typeof obj === 'object' || typeof obj === 'function') &&
            typeof obj.then === 'function');
    }
    /**
     * Metodo para validar que un objecto es una function
     * @param obj Objecto a validar
     */
    static isFunction(obj) {
        return obj && typeof obj === 'function';
    }
    static key() {
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, (c) => {
            // tslint:disable-next-line: no-bitwise
            const r = (Math.random() * 16) | 0;
            // tslint:disable-next-line: no-bitwise
            const v = c === 'x' ? r : (r & 0x3) | 0x8;
            return v.toString(16);
        });
    }
    /**
     * Metodo para validar que se pasa una configuracion correcta
     * de configuracion de Forks
     * @param toBeDetermined elemento a validar.
     */
    static isConfForkValid(toBeDetermined) {
        if (toBeDetermined.type) {
            return true;
        }
        return false;
    }
    /**
     * Get a nested object property value
     * Checks for a nested object property and returns its value.
     * @param   {object}    obj     An object given
     * @param   {string}    key     The needed key
     * @return  {string}            The value of that key.
     */
    get(key, target = null) {
        if (key) {
            return key.split('.').reduce((o, x) => {
                return typeof o === 'undefined' || o === null ? o : o[x];
            }, target ? target : this);
        }
        return undefined;
    }
    /**
     * Get a nested object property value
     * Checks for a nested object property and returns its value.
     * @param   {object}    obj     An object given
     * @param   {string}    key     The needed key
     * @return  {string}            The value of that key.
     */
    has(key) {
        return util_1.isUndefined(this.get(key));
    }
    /**
     * Metodo para la conversion de un objecto en array-like
     * @param   {object}    data    Objecto a convertir
     * @return  {object}            Resultado de la conversion
     */
    arrayLike(data) {
        const result = {};
        let cont = 0;
        for (const v of data) {
            result[cont] = v;
            cont++;
        }
        return result;
    }
}
exports.default = Util;
/**
 *  Metodo que regresa la cadena
 */
function getBroker() {
    if (process.env.KAFKA) {
        return process.env.KAFKA ? process.env.KAFKA.split(',') : [];
    }
    else if (process.env.NATS) {
        return process.env.NATS ? process.env.NATS.split(',') : [];
    }
    else {
        throw new Error('No se indico un broker correcto');
    }
}
exports.getBroker = getBroker;
